# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/shyster',
                'doc_host': 'https://jkseppan.github.io',
                'git_url': 'https://github.com/jkseppan/shyster',
                'lib_path': 'shyster'},
  'syms': { 'shyster.file': {'shyster.file.read_patterns': ('file.html#read_patterns', 'shyster/file.py')},
            'shyster.html': { 'shyster.html.analyze_soups': ('html.html#analyze_soups', 'shyster/html.py'),
                              'shyster.html.hyphenate_soup': ('html.html#hyphenate_soup', 'shyster/html.py')},
            'shyster.hyphenation': { 'shyster.hyphenation.add_hyphens': ('hyphenation.html#add_hyphens', 'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator': ('hyphenation.html#hyphenator', 'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator.__call__': ( 'hyphenation.html#hyphenator.__call__',
                                                                                  'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator.__init__': ( 'hyphenation.html#hyphenator.__init__',
                                                                                  'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator.add_exception': ( 'hyphenation.html#hyphenator.add_exception',
                                                                                       'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator.add_prefix_exception': ( 'hyphenation.html#hyphenator.add_prefix_exception',
                                                                                              'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator.hyphenate': ( 'hyphenation.html#hyphenator.hyphenate',
                                                                                   'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator.rm_exception': ( 'hyphenation.html#hyphenator.rm_exception',
                                                                                      'shyster/hyphenation.py'),
                                     'shyster.hyphenation.hyphenator.rm_prefix_exception': ( 'hyphenation.html#hyphenator.rm_prefix_exception',
                                                                                             'shyster/hyphenation.py')},
            'shyster.main': {'shyster.main.hyphenate_html_file': ('main.html#hyphenate_html_file', 'shyster/main.py')},
            'shyster.pattern': { 'shyster.pattern._cvt': ('pattern.html#_cvt', 'shyster/pattern.py'),
                                 'shyster.pattern.convert_exceptions': ('pattern.html#convert_exceptions', 'shyster/pattern.py'),
                                 'shyster.pattern.convert_patterns': ('pattern.html#convert_patterns', 'shyster/pattern.py')}}}